@@ -1,21 +1,9 @@
 /*
- * Copyright © 2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #ifndef XDG_DESKTOP_PORTAL_KDE_WAYLAND_INTEGRATION_P_H
@@ -30,22 +18,23 @@
 class Screencasting;
 class ScreencastingStream;
 
-namespace KWayland {
-    namespace Client {
-        class ConnectionThread;
-        class EventQueue;
-        class Registry;
-        class PlasmaWindow;
-        class PlasmaWindowManagement;
-        class FakeInput;
-        class RemoteBuffer;
-        class Output;
-    }
+namespace KWayland
+{
+namespace Client
+{
+class ConnectionThread;
+class EventQueue;
+class Registry;
+class PlasmaWindow;
+class PlasmaWindowManagement;
+class FakeInput;
+class RemoteBuffer;
+class Output;
+}
 }
 
 namespace WaylandIntegration
 {
-
 class WaylandIntegrationPrivate : public WaylandIntegration::WaylandIntegration
 {
     Q_OBJECT
@@ -118,7 +107,7 @@ private:
     QPoint m_streamedScreenPosition;
 
     QMap<quint32, WaylandOutput> m_outputMap;
-    QList<KWayland::Client::Output*> m_bindOutputs;
+    QList<KWayland::Client::Output *> m_bindOutputs;
 
     KWayland::Client::FakeInput *m_fakeInput = nullptr;
     Screencasting *m_screencasting = nullptr;
@@ -127,5 +116,3 @@ private:
 }
 
 #endif // XDG_DESKTOP_PORTAL_KDE_WAYLAND_INTEGRATION_P_H
-
-
